Author: https://www.facebook.com/mphoebegavin
Description: Things that matter. Pass 'em on.

Close
Share on Facebook

## What A Service Dog Really Thinks Of The Injured Vet Who Owns Him

Follow @ohsoordinary

I hope every vet who needs a Benji gets a Benji.

Share On Facebook
Share On TwitterTweet

To learn more about Benji the golden retriever and his owner, Joe, click play.

Share on Facebook
Share on Twitter
Share on Facebook

#### Next bit of Upworthiness:

## Want more stuff like this?

We're on a mission to spread meaningful content far and wide. Try our daily email, The Upworthiest, and see for yourself!

By submitting above you agree to the Upworthy privacy policy.

One-Click Subscribe

No time to type on that tiny screen? No problem! Click subscribe above, then hit send when the email pops up. Boom, you're done.

## Thanks for signing up!

Nice! Like us on Facebook to add daily goodness to your feed:

Nice! Subscribe to our YouTube channel to stay tuned to the most meaningful videos on the web.

## Want More Good Stuff?

Subscribe to our YouTube channel to stay tuned to the most meaningful videos on the web.

- ###

### Flash Video Embed

This video is not supported by your device. Continue browsing to find other stuff you'll love!

Close
Pinch or double-tap to zoom

Hey, Internet Friend. Looks like you're using a crazy old web browser, which is no longer supported. Please consider upgrading to something more modern—for a better experience, and a safer time online. We only want the best for you.

Download Google Chrome, and try it for a week. Don't think about it, just do it. You'll thank us later.